# music-tool-kit 音乐工具箱

## 安装

```bash
pip install -U music-tool-kit
```

## 使用

- 音乐下载

```bash
mk  网址 [输出] [封面url]
```

> tips: 输出格式为 歌曲名-歌手(专辑名) 输出歌曲格式为 mp3 可选, 封面 url 也可选

- 音乐剪辑

```bash
mk -c 输入的文件 开始时间 结束时间
```

> tips: 时间格式为: 00:00:00
